// (c) UK Andrew Giddings 2003
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public Licence as published by the
// Free Software Foundation; either version 2 of the Licence, or (at your
// option) any later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence
// for more details.  (http://www.gnu.org/licenses/gpl.txt)

package uk.co.cix.gidds.io;

import java.awt.*;
import java.io.*;

/*******************************************************************************
* This Writer appends its input to a TextField or TextArea.
* This allows us to trap the output from the compiler, etc.
* It buffers input a line at a time, avoiding a final newline.
*
* @author Andrew Giddings
*******************************************************************************/

public class TextAreaWriter
	extends Writer
{
	TextArea area;
	StringBuffer sb = new StringBuffer(80);
	boolean closed = false;

	public TextAreaWriter(TextArea area)
	{
		this.area = area;
	}

	public void write(char[] c, int off, int len)
		throws IOException
	{
		if (closed)
			throw new IOException("Stream closed");

		int i;

		// Contains a CR?
		for (i = off + len - 1; i >= off; --i)
			if (c[i] == '\n')
				break;
		// If so, write up to (but not including) the CR to the area.
		if (i >= off)
		{	sb.append(c, off, i - off);
			flush();
			sb.append(c, i, len + off - i);
		}
		else
			sb.append(c, off, len);
	}

	public void flush()
		throws IOException
	{
		if (closed)
			throw new IOException("Stream closed");

		area.append(sb.toString());
		sb.setLength(0);
	}

	public void close()
		throws IOException
	{
		if (closed)
			throw new IOException("Stream closed");

		flush();
		closed = true;
	}
}
