// (c) UK Andrew Giddings 2003
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public Licence as published by the
// Free Software Foundation; either version 2 of the Licence, or (at your
// option) any later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence
// for more details.  (http://www.gnu.org/licenses/gpl.txt)

package uk.co.cix.gidds.ui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.table.*;

/*******************************************************************************
* Various (Swing) UI-related functions.
*
* @author Andrew Giddings
*******************************************************************************/

public final class JUIUtils
{
	private static MouseListener dummyMouseListener;

	public static void initHourglass(RootPaneContainer c)
	{
		if (dummyMouseListener == null)
			dummyMouseListener = new MouseAdapter() {};

		c.getGlassPane().addMouseListener(dummyMouseListener);
		c.getGlassPane().setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
	}

	public static void setHourglass(JComponent c, boolean hourglass)
	{
		c.getRootPane().getGlassPane().setVisible(hourglass);
	}

	public static void setHourglass(RootPaneContainer c, boolean hourglass)
	{
		c.getGlassPane().setVisible(hourglass);
	}

	/**
	* Set the width of each column in a JTable to that of the widest value.
	* Inspired by from http://java.sun.com/docs/books/tutorial/uiswing/components/example-1dot4/TableRenderDemo.java
	**/
	public static void setColumnWidths(JTable table, int maxWidth)
	{
		TableModel model = table.getModel();
		int columns = model.getColumnCount();
		int rows = model.getRowCount();
		TableCellRenderer headerRenderer = table.getTableHeader().getDefaultRenderer();

		for (int columnIndex = 0; columnIndex < columns; ++columnIndex)
		{
			TableColumn column = table.getColumnModel().getColumn(columnIndex);
			Component comp = headerRenderer.getTableCellRendererComponent(table, column.getHeaderValue(), false, false, 0, columnIndex);
			int greatestWidth = comp.getPreferredSize().width + 1;
			TableCellRenderer columnRenderer = table.getDefaultRenderer(model.getColumnClass(columnIndex));

			for (int row = 0; row < rows && greatestWidth < maxWidth; ++row)
			{	comp = columnRenderer.getTableCellRendererComponent(table, model.getValueAt(row, columnIndex), false, false, row, columnIndex);
				int width = comp.getPreferredSize().width + 1;
				if (greatestWidth < width)
					greatestWidth = width;
			}
			column.setPreferredWidth(Math.min(maxWidth, greatestWidth));
		}
	}
}
