// (c) UK Andrew Giddings 2003
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public Licence as published by the
// Free Software Foundation; either version 2 of the Licence, or (at your
// option) any later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence
// for more details.  (http://www.gnu.org/licenses/gpl.txt)

package uk.co.cix.gidds.ui;

import java.awt.*;

/*******************************************************************************
* Various (AWT) UI-related functions.
*
* @author Andrew Giddings
*******************************************************************************/

public final class UIUtils
{
	public static final Font DEFAULT_FONT = new Font("SansSerif", Font.PLAIN, 15);

	public static void centreOnScreen(Component c)
	{
		reduceToScreenSize(c);
		Dimension size = c.getSize();
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		c.setLocation((screenSize.width - size.width) / 2,
					(screenSize.height - size.height) / 2);
	}

	public static void centreOverComponent(Component c, Component parent)
	{
		if (parent.isShowing())
		{	Dimension size = c.getSize();
			Point parentLoc = parent.getLocationOnScreen();
			Dimension parentSize = parent.getSize();
			c.setLocation(parentLoc.x + (parentSize.width - size.width) / 2,
				parentLoc.y + (parentSize.height - size.height) / 2);
		}
		else
			centreOnScreen(c);
	}

	public static void reduceToScreenSize(Component c)
	{
		Dimension size = c.getSize();
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		if (size.width > screenSize.width || size.height > screenSize.height)
			c.setSize((size.width > screenSize.width)
									? screenSize.width : size.width,
						(size.height > screenSize.height)
									? screenSize.height : size.height);
	}

	/**
	* Expand a window to its preferred size (plus an extra amount).
	* The result is centred over its original position.
	* If it's this size or more already, does NOT contract the window.
	**/
	public static void expandToPreferredSize(Window w, int extraX, int extraY)
	{
		Rectangle bounds = w.getBounds();

		Dimension prefSize = w.getPreferredSize();
		prefSize.width = Math.max(prefSize.width + extraX, bounds.width);
		prefSize.height = Math.max(prefSize.height + extraY, bounds.height);

		if (prefSize.width > bounds.width || prefSize.height > bounds.height)
		{	bounds.x -= (prefSize.width - bounds.width) / 2;
			bounds.y -= (prefSize.height - bounds.height) / 2;
			bounds.width = prefSize.width;
			bounds.height = prefSize.height;

			w.setBounds(bounds);
			w.validate();
		}
	}
}
